@@ -128,11 +128,11 @@ class EndpointEnumerator(_EndpointEnumerator):
         :param str s: string with backslash escapes
         :rtype: str
         """
-        # unlike .replace('\\', ''), this corectly transforms a double backslash into a single backslash
+        # unlike .replace('\\', ''), this correctly transforms a double backslash into a single backslash
         return re.sub(r'\\(.)', r'\1', s)
 
     def unescape_path(self, path):
-        """Remove backslashe escapes from all path components outside {parameters}. This is needed because
+        """Remove backslashes escapes from all path components outside {parameters}. This is needed because
         ``simplify_regex`` does not handle this correctly.
 
         **NOTE:** this might destructively affect some url regex patterns that contain metacharacters (e.g. \\w, \\d)
@@ -195,6 +195,8 @@ class OpenAPISchemaGenerator(object):
                 raise SwaggerGenerationError("`url` must be an absolute HTTP(S) url")
             if parsed_url.path:
                 logger.warning("path component of api base URL %s is ignored; use FORCE_SCRIPT_NAME instead" % url)
+            else:
+                self._gen.url = url
 
     @property
     def url(self):
@@ -431,8 +433,8 @@ class OpenAPISchemaGenerator(object):
         operation_keys = self.get_operation_keys(path[len(prefix):], method, view)
         overrides = self.get_overrides(view, method)
 
-        # the inspector class can be specified, in decreasing order of priorty,
-        #   1. globaly via DEFAULT_AUTO_SCHEMA_CLASS
+        # the inspector class can be specified, in decreasing order of priority,
+        #   1. globally via DEFAULT_AUTO_SCHEMA_CLASS
         view_inspector_cls = swagger_settings.DEFAULT_AUTO_SCHEMA_CLASS
         #   2. on the view/viewset class
         view_inspector_cls = getattr(view, 'swagger_schema', view_inspector_cls)
